<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Der findes liv udenfor browseren!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Version %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenseret til: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 er fri software, men udviklingen tager værdifuld tid.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Venligst &lt;a href=&apos;%1&apos;&gt;doner&lt;/a&gt; for at støtte den forsatte udvikling af %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Oversæt %1 til din modersmål ved hjælp af %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>Styrket af 1%</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Åben-Kildekode software</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon designet af %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Frigivet under &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Indtast dine licensoplysninger</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kode:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Venligst licensér %1</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Den fulde version giver dig mulighed for, at se videoer uden afbrydelser.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ved at købe den fulde version, støtter du også støtte det hårde arbejde jeg lagt i at udvikle %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Brug prøveversion</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Indtast licens</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Køb licens</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Hent</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Af %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Alle videoer</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videoer, der ikke er set</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Senest opdateret</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Senest tilføjet</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Sidst set</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Mest set</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sorter efter</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marker alle som set</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Show opdateret</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Du har ingen abonnementer. Brug stjernetegnet til at abonnere på kanaler.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Alle videoer</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videoer, der ikke er set</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marker som set</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Afmeld</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Der er ingen opdateringer i de abonnerede.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Lige nu</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visninger</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sek</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sek</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sek</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 mangler</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 downloaded på %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Download afsluttet</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Skift placering...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Vælg placering til downloads</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Downloadplacering ændret.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Nuværende downloads vil stadig blive glemt i forrige placering.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Downloader til: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Den eksekverbare fil er blevet manipuleret, muligvis af en virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 kører ikke. Prøv at geninstallere.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Afslut</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Geninstaller</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Afspil</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Afspil/Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Stop afspilning efter det aktuelle spor</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Næste spor</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Forrige spor</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Skru op</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Skru ned</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Slå lyden fra</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Søg fremad</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Søg baglæns</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Find videoer og kanaler via søgeord</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Gennemse</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Gennemse videoer efter kategori</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Abonnementer</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Abonnementer på kanaler</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Sæt dig godt til rette</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Vindue</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimize</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stop</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Stop afspilning og gå tilbage til søgeoversigt</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>F&amp;orrige</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Gå tilbage til forrige nummer</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>S&amp;pring over</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Spring til næste video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Afspil</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Genoptag afspilning</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Fuldskærm</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Vis i fuldskærm</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Skjul afspilningslisten og værktøjslinjen</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Åbn &amp;Youtube-siden</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Gå til YouTube-videosiden og pause afspilningen</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopier &amp;link til Youtube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopier det aktuelle YouTube-videolink til udklipsholderen</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>	
Kopiér &amp;URL&apos;en til videostrømmen</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopier adressen for den aktuelle videostrøm til udklipsholderen</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Find dele af videoen</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Find andre videodele forhåbentlig i den rigtige rækkefølge</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Fjern</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Fjern de valgte videoer fra afspilningslisten</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Flyt &amp;Op</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Flyt de valgte videoer i afspilningslisten op</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Flyt &amp;Ned</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Flyt de valgte videoer i afspilningslisten ned</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Ryd seneste søgninger</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Ryd søgeoversigt. Kan ikke fortrydes.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Farvel</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Hjemmeside</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 på nettet</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Giv en &amp;Donation</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Støt den forsatte udvikling af %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info om %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Slå lyden fra</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Start afspilning &amp;manuelt</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Start afspilning af videoer manuelt</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Downloads</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Vis deltaljer om video downloads</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Download</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Download den aktuelle video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Tag $Skærmbillede</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Abonner på kanal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Del den aktuelle video ved hjælp af %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;amp; E-mail</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Behold øverst</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Stop efter denne video</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Rapporter et problem...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Indskrænk søgning...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Mere...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Relaterede videoer</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Se videoer relateret til den nuværende</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Åbn i &amp;browser...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Begrænset-Måde</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Gem videoer der muligvis indeholder stødene indhold.</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>%Vild med %1? Bedøm det!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Køb %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Program</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Afspil</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Afspilningsliste</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Del</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Tryk %1 for at skrue op for lyden og %2 for at skrue ned</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Vælg placering for dit indhold</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Åbner %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Vil du afslutte %1 selvom et download er i gang?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Hvis du lukker %1 nu vil dette download blive annulleret. </translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Luk og annuller download </translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Vent til download er færdig</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Fejl: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pause afspilning</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Loader...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Forlad &amp;Fuld skærm</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tilbageværende tid: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Lydniveau på %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Lyden er slået fra</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Lyden er slået til</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Maksimal videoopløsning sat til %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Dit privatliv er nu sikret</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Downloads færdig</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Du kan nu indsætte YouTube-linket i et andet program</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Du kan nu indsætte adressen til videostrømmen i et andet program</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Linket vil kun være gyldigt i en begrænset periode.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Downloader %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>af</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>del</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episode</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Sendt fra %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Fjern abonnement fra %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Abonner på %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Abonnerer ikke længere på %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Abonnerer nu på %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>En ny version af %1 er tilgængelig!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 er tilgængelig. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Ønsker du at hente den nu?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Spring denne version over</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Påmind mig senere</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Installér opdatering</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Indsæt</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 af %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Forbereder</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Fuldendt</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppet</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Stop download</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>VIs i %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Åben ovenstående mappe</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Genstart download</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Vis %1 mere</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ingen videoer</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ikke flere videoer</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sorter efter</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Antal visninger</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Bedømmelse</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Når som helst</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>I dag</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 dage</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 dage</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varighed</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medium</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Mindre end 4 minutter</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Mellem 4 og 20 minutter</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Længere end 20 minutter</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kvalitet</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Afsluttet</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Afslut</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Søg</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Velkommen til &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>for at  begynde at se video.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>et nøgleord</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Indtast</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Seneste nøgleord</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Nyeste kanaler</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hent den fulde version</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Tilbage</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Frem til %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Tilbage til %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Indskrænk søgning</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Mente du: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Skift placering...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Skærmbillede gemt på %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Lokation for skærmbilleder ændret.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Mest populære</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Henter opdatering...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Henter %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Henter opdatering...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikke hente videostrøm for %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeriet</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Austalien</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgien</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasilien</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tjekkiet</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypten</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Frankrig</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Tyskland</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grækenland</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Ungarn</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Indien</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesien</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irland</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italien</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japan</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malaysia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexico</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Nederlandende</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>New Zealand</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Philipinierne</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polen</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusland</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabien</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sydfrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sydkorea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanien</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Sverige</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisien</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Tyrkiet</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Forenede Arabiske Emirater</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Storbritanien</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Hele verden</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Kan ikke hente videostrøm for %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>En ny version af %1 er tilgængelig!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 er tilgængelig. Du har %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Ønsker du at hente den nu?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Påmind mig senere</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>